fmatch: Fast string matching with limited wildcard support

Description Usage Arguments Value

Description

For each string in x, find the find match in y. The character '?' is treated as a wildcard in both x and y.

Usage

1
fmatch(x, y)

Arguments

x

character

y

character

Value

integer positions of matches in y (NA indicates no match)


holstius/fmatch documentation built on May 17, 2019, 4:50 p.m.