Description Usage Arguments Value
For each string in x, find the find match in y.
The character '?' is treated as a wildcard in both x and y.
1 | fmatch(x, y)
|
x |
character |
y |
character |
integer positions of matches in y (NA indicates no match)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.